==> slds-input-radio-group-0.1.0.tgz: package/input-radio-group.js <==
/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
  Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */
import { fragmentFrom, templateFrom } from 'elix/src/core/htmlLiterals.js';
import { template, render, setState, state } from 'elix/src/base/internal';
import { ReactiveElement } from 'elix';
import { reflectAttribute } from '@salesforce-ux/sds-utils';
import common from '@salesforce-ux/sds-common/common.module.css';
import SdsInputRadioGroupCss from '@salesforce-ux/sds-input-radio-group/input-radio-group.module.css';
import SdsInputRadioCss from '@salesforce-ux/sds-input-radio/input-radio.module.css';
import { nanoid } from 'nanoid';

import html from './input-radio-group.html';
import css from './input-radio-group.module.css';

/**
 * > FOR TESTING ONLY <
 *
 * This component represents the native shadow DOM half of mixed-mode. Mixed-mode
 * currently requires markup and CSS to be the same in both modes. So we are
 * implementing a monolithic version of sds-input-radio and sds-input-radio-group.
 * The monolithic version is comparable to lightning-radio.
 */
export class SldsInputRadioGroup extends ReactiveElement {
  get legend() {
    return this[state].legend;
  }

  set legend(legend) {
    this[setState]({ legend });
  }

  get name() {
    return this[state].name;
  }

  set name(name) {
    this[setState]({ name });
  }

  get orientation() {
    return this[state].orientation;
  }

  set orientation(orientation) {
    this[setState]({ orientation });
  }

  get options() {
    return this[state].options;
  }

  set options(options) {
    this[setState]({ options });
  }

  get required() {
    return this[state].required;
  }

  set required(required) {
    return this[setState]({ required });
  }

  get selectedOption() {
    return this[state].selectedOption;
  }

  set selectedOption(selectedOption) {
    return this[setState]({ selectedOption });
  }

  get disabled() {
    return this[state].disabled;
  }

  set disabled(disabled) {
    return this[setState]({ disabled });
  }

  get variant() {
    return this[state].variant;
  }

  set variant(variant) {
    return this[setState]({ variant });
  }

  [render](changed) {
    super[render](changed);
    const { legend, name, options, disabled, orientation, selectedOption, variant } = this[state];
    const radioGroupPart = this.shadowRoot.querySelector('[part~="input-radio-group"]');
    const legendPart = this.shadowRoot.querySelector('[part~="legend"]');
    const optionsPart = this.shadowRoot.querySelector('[part~="options"]');

    if (changed.legend) {
      legendPart.textContent = legend;
    }

    if (changed.name) {
      if (name) {
        this._setAttributeForRadios('name', name);
      }
    }

    if (changed.orientation) {
      radioGroupPart.setAttribute('aria-orientation', orientation);
    }

    if (changed.options) {
      optionsPart.innerHTML = options.map(this.radioTemplate(name)).join('');
      this._getRadios().forEach((radio) => {
        radio.addEventListener('click', (event) => this._handleChange(event.target));
      });
      // Update options state after the options have rendered
      if (disabled) {
        this.disableOptions();
      }

      if (selectedOption) {
        this.changeSelection(selectedOption);
      }
    }

    if (changed.required) {
      const legend = this.shadowRoot.querySelector('[part~="legend"]');

      // Text should be customizable based on i18n
      const requiredSymbol = `<abbr part="required" title="required">*</abbr>`;
      legend.prepend(fragmentFrom.html`${requiredSymbol}`);
    }

    if (changed.selectedOption && selectedOption) {
      this.changeSelection(selectedOption);
    }

    if (changed.disabled) {
      this.disableOptions();
    }

    if (changed.variant) {
      this._changeVariant(variant);
    }
  }

  get [template]() {
    const result = templateFrom.html`
        <style>
          ${css}
          ${SdsInputRadioGroupCss}
          ${SdsInputRadioCss}
          ${common}
        </style>
        ${html}
      `;

    return result;
  }

  disableOptions() {
    const radios = this._getRadios();

    if (this[state].disabled) {
      radios.forEach((radio) => radio.setAttribute('disabled', true));
    } else {
      radios.forEach((radio) => radio.removeAttribute('disabled'));
    }
  }

  changeSelection(selectedOption) {
    this._reset();
    const radio = this.shadowRoot.querySelector(`input[value="${selectedOption}"]`);
    radio && radio.setAttribute('checked', true);
  }

  radioTemplate(name) {
    return (option) => {
      const radioId = `radio-${nanoid(10)}`;
      return `<span class="slds-radio">
        <input type="radio"
                name="${name}"
                id='${radioId}'
                value='${option.value}'
                part='radio'
                >
        <label class="slds-radio__label" for='${radioId}' part="input-radio">
          <span class="slds-radio_faux" part="indicator"></span>
          <span class="slds-form-element__label"  part="label">${option.label}</span>
        </label>
    </span>`;
    };
  }

  _setAttributeForRadios(attrName, attrValue = '') {
    const radios = this._getRadios();
    radios.forEach((radio) => {
      reflectAttribute(radio, attrName, attrValue);
    });
  }

  _handleChange(selectedRadio) {
    selectedRadio && this[setState]({ selectedOption: selectedRadio.value });
  }

  _reset() {
    const radios = this._getRadios();
    radios.forEach((radio) => {
      radio.removeAttribute('checked');
    });
  }

  _getRadios() {
    const options = this.shadowRoot.querySelector('[part~="options"]');
    const radios = options && options.querySelectorAll('input[type="radio"]');
    return radios && radios.length ? radios : [];
  }

  /**
   * This is workaround to demo LBC variants on Storybook.
   * LBC adds those "form-element" SLDS classes to the host and we need to keep them for synthetic.
   * For Native, we leverage the attribute `variant` to add the proper class accordingly.
   * These classes are here to ensure that there is no interaction in the synthetic world.
   *
   */
  _changeVariant(variant) {
    const sldsFormElementLegend = this.shadowRoot.querySelector('.slds-form-element__legend');

    const variants = {
      standard: '',
      'label-hidden': 'slds-assistive-text',
      'label-inline': 'slds-form-element_horizontal',
      'label-stacked': 'slds-form-element_stacked',
    };
    const selectedVariant = variants[variant];

    if (variant === 'label-hidden') {
      sldsFormElementLegend.classList.add(selectedVariant);
    } else if (variant === 'label-inline') {
      this.classList.add(selectedVariant); /* Temporary hack to mimic LBC markup */
    } else if (variant === 'label-stacked') {
      this.classList.add(selectedVariant); /* Temporary hack to mimic LBC markup */
    }
  }
}

==> slds-input-radio-group-0.1.3.tgz: package/input-radio-group.js <==
/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
  Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */
import { fragmentFrom, templateFrom } from 'elix/src/core/htmlLiterals.js';
import { hasDynamicTemplate, render, setState, state, template } from 'elix/src/base/internal';
import { ReactiveElement } from 'elix';
import { reflectAttribute } from '@salesforce-ux/sds-utils';
import common from '@salesforce-ux/sds-common/common.module.css';
import SdsInputRadioGroupCss from '@salesforce-ux/sds-input-radio-group/input-radio-group.module.css';
import SdsInputRadioCss from '@salesforce-ux/sds-input-radio/input-radio.module.css';
import { nanoid } from 'nanoid';

import html from './input-radio-group.html';
import css from './input-radio-group.module.css';

/**
 * > FOR TESTING ONLY <
 *
 * This component represents the native shadow DOM half of mixed-mode. Mixed-mode
 * currently requires markup and CSS to be the same in both modes. So we are
 * implementing a monolithic version of sds-input-radio and sds-input-radio-group.
 * The monolithic version is comparable to lightning-radio.
 */
export class SldsInputRadioGroup extends ReactiveElement {
  get [hasDynamicTemplate]() {
    return true;
  }

  get legend() {
    return this[state].legend;
  }

  set legend(legend) {
    this[setState]({ legend });
  }

  get name() {
    return this[state].name;
  }

  set name(name) {
    this[setState]({ name });
  }

  get type() {
    return this[state].type;
  }

  set type(type) {
    return this[setState]({ type });
  }

  get orientation() {
    return this[state].orientation;
  }

  set orientation(orientation) {
    this[setState]({ orientation });
  }

  get options() {
    return this[state].options;
  }

  set options(options) {
    this[setState]({ options });
  }

  get required() {
    return this[state].required;
  }

  set required(required) {
    return this[setState]({ required });
  }

  get selectedOption() {
    return this[state].selectedOption;
  }

  set selectedOption(selectedOption) {
    return this[setState]({ selectedOption });
  }

  get disabled() {
    return this[state].disabled;
  }

  set disabled(disabled) {
    return this[setState]({ disabled });
  }

  get variant() {
    return this[state].variant;
  }

  set variant(variant) {
    return this[setState]({ variant });
  }

  [render](changed) {
    super[render](changed);
    const { legend, name, type, options, disabled, orientation, selectedOption, variant } = this[state];
    const radioGroupPart = this.shadowRoot.querySelector('[part~="input-radio-group"]');
    const legendPart = this.shadowRoot.querySelector('[part~="legend"]');
    const optionsPart = this.shadowRoot.querySelector('[part~="options"]');

    if (changed.legend) {
      legendPart.textContent = legend;
    }

    if (changed.name) {
      if (name) {
        this._setAttributeForRadios('name', name);
      }
    }

    if (changed.type) {
      if (type) {
        this.setAttribute('type', type);
      }
    }

    if (changed.orientation) {
      radioGroupPart.setAttribute('aria-orientation', orientation);
    }

    if (changed.options) {
      if (type === 'radio') {
        optionsPart.innerHTML = options.map(this.radioTemplate(name)).join('');
      } else {
        // firstElementChild is the div.slds-radio_button-group
        optionsPart.firstElementChild.innerHTML = options.map(this.radioButtonTemplate(name)).join('');
      }

      this._getRadios().forEach((radio) => {
        radio.addEventListener('click', (event) => this._handleChange(event.target));
      });
      // Update options state after the options have rendered
      if (disabled) {
        this.disableOptions();
      }

      if (selectedOption) {
        this.changeSelection(selectedOption);
      }
    }

    if (changed.required) {
      const legend = this.shadowRoot.querySelector('[part~="legend"]');

      // Text should be customizable based on i18n
      const requiredSymbol = `<abbr part="required" title="required">*</abbr>`;
      legend.prepend(fragmentFrom.html`${requiredSymbol}`);
    }

    if (changed.selectedOption && selectedOption) {
      this.changeSelection(selectedOption);
    }

    if (changed.disabled) {
      this.disableOptions();
    }

    if (changed.variant) {
      this._changeVariant(variant);
    }
  }

  get [template]() {
    const result = templateFrom.html`
        <style>
          ${css}
          ${SdsInputRadioGroupCss}
          ${SdsInputRadioCss}
          ${common}
        </style>
        ${html}
      `;

    // Populate markup dependent on type
    const { type } = this[state];
    const legendPart = result.content.querySelector('[part~="legend"]');
    const optionsPart = result.content.querySelector('[part~="options"]');
    const typeRadioOptionsPart = this.createTypeRadioOptionsPart();
    const typeButtonOptionsPart = this.createTypeButtonOptionsPart();

    if (type === 'radio') {
      optionsPart.remove();
      legendPart.insertAdjacentHTML('afterend', typeRadioOptionsPart);
    } else {
      optionsPart.remove();
      legendPart.insertAdjacentHTML('afterend', typeButtonOptionsPart);
    }

    return result;
  }

  disableOptions() {
    const radios = this._getRadios();

    if (this[state].disabled) {
      radios.forEach((radio) => radio.setAttribute('disabled', true));
    } else {
      radios.forEach((radio) => radio.removeAttribute('disabled'));
    }
  }

  changeSelection(selectedOption) {
    this._reset();
    const radio = this.shadowRoot.querySelector(`input[value="${selectedOption}"]`);
    radio && radio.setAttribute('checked', true);
  }

  // Type Radio
  createTypeRadioOptionsPart() {
    const dynamicTemplate = `
      <div class="slds-form-element__control" part="options"></div>
    `;

    return dynamicTemplate;
  }

  radioTemplate(name) {
    return (option) => {
      const radioId = `radio-${nanoid(10)}`;
      return `
        <span class="slds-radio">
          <input type="radio"
                  name="${name}"
                  id='${radioId}'
                  value='${option.value}'
                  part='radio'
                  >
          <label class="slds-radio__label" for='${radioId}' part="input-radio">
            <span class="slds-radio_faux" part="indicator"></span>
            <span class="slds-form-element__label"  part="label">${option.label}</span>
          </label>
      </span>
    `;
    };
  }

  // Type Button
  createTypeButtonOptionsPart() {
    const dynamicTemplate = `
      <div class="slds-form-element__control" part="options">
        <div class="slds-radio_button-group"></div>
      </div>
    `;

    return dynamicTemplate;
  }

  radioButtonTemplate(name) {
    return (option) => {
      const radioId = `radio-${nanoid(10)}`;
      return `
        <span class="slds-button slds-radio_button">
          <input type="radio"
                  name="${name}"
                  id='${radioId}'
                  value='${option.value}'
                  part='radio'
                  >
          <label class="slds-radio_button__label" for='${radioId}'>
            <span class="slds-radio_faux">${option.label}</span>
          </label>
        </span>
      `;
    };
  }

  _setAttributeForRadios(attrName, attrValue = '') {
    const radios = this._getRadios();
    radios.forEach((radio) => {
      reflectAttribute(radio, attrName, attrValue);
    });
  }

  _handleChange(selectedRadio) {
    selectedRadio && this[setState]({ selectedOption: selectedRadio.value });
  }

  _reset() {
    const radios = this._getRadios();
    radios.forEach((radio) => {
      radio.removeAttribute('checked');
    });
  }

  _getRadios() {
    const options = this.shadowRoot.querySelector('[part~="options"]');
    const radios = options && options.querySelectorAll('input[type="radio"]');
    return radios && radios.length ? radios : [];
  }

  /**
   * This is workaround to demo LBC variants on Storybook.
   * LBC adds those "form-element" SLDS classes to the host and we need to keep them for synthetic.
   * For Native, we leverage the attribute `variant` to add the proper class accordingly.
   * These classes are here to ensure that there is no interaction in the synthetic world.
   *
   */
  _changeVariant(variant) {
    const sldsFormElementLegend = this.shadowRoot.querySelector('.slds-form-element__legend');

    const variants = {
      standard: '',
      'label-hidden': 'slds-assistive-text',
      'label-inline': 'slds-form-element_horizontal',
      'label-stacked': 'slds-form-element_stacked',
    };
    const selectedVariant = variants[variant];

    if (variant === 'label-hidden') {
      sldsFormElementLegend.classList.add(selectedVariant);
    } else if (variant === 'label-inline') {
      this.classList.add(selectedVariant); /* Temporary hack to mimic LBC markup */
    } else if (variant === 'label-stacked') {
      this.classList.add(selectedVariant); /* Temporary hack to mimic LBC markup */
    }
  }
}
